@@ -9,12 +9,13 @@ ROBOT_ERROR_MESSAGE = (
 
 def fetch_html(url):
     response = requests.get(url)
-    text = response.text
     if response.status_code != 200:
-        raise FetchError(f"Fetch error for: {url}")
-    elif ROBOT_ERROR_MESSAGE in text:
+        raise FetchError(
+            f"Fetch error for: {url}. [status_code={response.status_code}, body={response.text}]"
+        )
+    elif ROBOT_ERROR_MESSAGE in response.text:
         raise YelpRobotError()
-    return text
+    return response.text
 
 
 def fetch_soup(url):
