@@ -1,7 +1,7 @@
 from enum import Enum
 from typing import TypedDict
 
-from yelp_fetcher._util import fetch_html
+from yelp_fetcher._util import FetchError, fetch_html
 from yelp_fetcher.scraper.biz import get_biz_review_url, review_id_on_page
 
 
@@ -26,6 +26,4 @@ def fetch_status(user_id, biz_id, review_id):
     except FetchError:
         status = Status.UNKNOWN
 
-    return ReviewStatus(
-        user_id=user_id, biz_id=biz_id, review_id=review_id, status=status.value
-    )
+    return ReviewStatus(user_id=user_id, biz_id=biz_id, review_id=review_id, status=status.value)
